# Phinder

This program generates pharmacophore models using GNINA 1.0 docked fragments to cluster into pharmacophore features.


## Help

Please contact Dillon Gavlock at dcg33@pitt.edu


## Installation

Install goes here


## Usage

Usage goes here

## Citation

Please cite us here

## License

phinder is dual licensed under GPL and Apache. The GPL license is necessitated by the use of OpenBabel (which is GPL licensed). In order to use phinder under the Apache license only, all references to OpenBabel must be removed from the source code.

 
